==> frontend-stack-react-4.0.2-alpha.18.tgz: package/lib/config/base-apollo-client.js <==
import {isBoolean,merge}from'lodash-es';import {ApolloLink,ApolloClient}from'@apollo/client/index.js';import {HttpLink}from'@apollo/client/link/http/index.js';import {BatchHttpLink}from'@apollo/client/link/batch-http/index.js';import {onError}from'@apollo/client/link/error/index.js';import {GraphQLWsLink}from'@apollo/client/link/subscriptions/index.js';import {getOperationAST}from'graphql';import {invariant}from'ts-invariant';import {RetryLink}from'@apollo/client/link/retry/index.js';import {createClient}from'graphql-ws';import fetch from'cross-fetch';import {createCache,initializeCache}from'./base-apollo-cache.js';// apolloClient.ts
const schema = `
  # Add your schema here
`;
const errorLink = onError(({ graphQLErrors, networkError }) => {
    if (graphQLErrors) {
        graphQLErrors.map(({ message, locations, path }) => invariant.warn(`[GraphQL error]: Message: ${message}, Location: ${locations}, Path: ${path}`));
    }
    if (networkError) {
        invariant.warn(`[Network error]: ${networkError}`);
    }
});
const createApolloClient = ({ scope, isDev, isDebug, isSSR, getDataIdFromObject, clientState, httpGraphqlURL, httpLocalGraphqlURL, initialState, logger, }) => {
    logger.debug('Initializing Apollo Client with parameters, {%o}', {
        scope,
        isDev,
        isDebug,
        isSSR,
        httpGraphqlURL,
        httpLocalGraphqlURL,
    });
    const isBrowser = scope === 'browser';
    const isServer = scope === 'server';
    const cache = createCache({ getDataIdFromObject, clientState, logger });
    logger.debug('Created new Apollo memory cache');
    const retryLink = new RetryLink({
        attempts: async (count, operation, error) => {
            logger.debug('Retrying link attempt', { count, operation, error });
            const promises = (clientState.retryLinkAttemptFuncs || []).map((func) => func(count, operation, error));
            try {
                const result = await Promise.all(promises);
                return !!result.find((item) => item && isBoolean(item));
            }
            catch (e) {
                logger.error('Error occurred in retryLink attempt condition', e);
                throw e;
            }
        },
    });
    let link;
    if (isBrowser) {
        const connectionParams = async () => {
            logger.debug('Getting WebSocket connection parameters');
            const param = {};
            for (const connectionParam of clientState.connectionParams) {
                const result = await connectionParam();
                merge(param, await result());
            }
            return param;
        };
        const wsLink = new GraphQLWsLink(createClient({
            url: httpGraphqlURL.replace(/^http/, 'ws'),
            retryAttempts: 10,
            lazy: true,
            shouldRetry: () => true,
            keepAlive: 10000,
            connectionParams,
            on: {
                connected: (socket) => logger.debug('WebSocket connected'),
                error: async (error) => {
                    logger.error('WebSocket connection error', error);
                    const promises = (clientState.connectionCallbackFuncs || []).map((func) => func(wsLink, error, {}));
                    try {
                        await Promise.all(promises);
                    }
                    catch (err) {
                        logger.trace('Error occurred in WebSocket connection callback', err);
                        throw err;
                    }
                },
                ping: () => logger.trace('WebSocket ping sent'),
                pong: () => logger.trace('WebSocket pong received'),
            },
        }));
        link = ApolloLink.split(({ query, operationName }) => {
            if (operationName.endsWith('_WS')) {
                return true;
            }
            const operationAST = getOperationAST(query, operationName);
            return !!operationAST && operationAST.operation === 'subscription';
        }, wsLink, new HttpLink({ uri: httpGraphqlURL, credentials: 'include', fetch }));
    }
    else if (isServer) {
        logger.debug('Creating BatchHttpLink for server');
        link = new BatchHttpLink({
            uri: httpLocalGraphqlURL,
            fetch,
            batchInterval: 200,
            batchMax: 100,
            credentials: 'include',
        });
    }
    else {
        logger.debug('Creating HttpLink for native');
        link = new HttpLink({ uri: httpLocalGraphqlURL, fetch, credentials: 'include' });
    }
    const links = [errorLink, retryLink, ...(clientState.preLinks || []), link].filter(Boolean);
    const params = {
        queryDeduplication: true,
        typeDefs: schema.concat(clientState.typeDefs || ''),
        resolvers: clientState.resolvers,
        link: ApolloLink.from(links),
        cache,
        credentials: 'include',
        connectToDevTools: isBrowser && (isDev || isDebug),
    };
    if (isSSR) {
        if (isBrowser) {
            params.ssrForceFetchDelay = 100;
        }
        else if (isServer) {
            params.ssrMode = true;
        }
    }
    const apolloClient = new ApolloClient(params);
    logger.debug('Created new Apollo client');
    initializeCache({ cache, initialState, clientState, logger });
    return { apolloClient, cache };
};export{createApolloClient};

==> frontend-stack-react-6.0.6-alpha.18.tgz: package/lib/config/base-apollo-client.js <==
import {merge}from'lodash-es';import {ApolloLink,ApolloClient}from'@apollo/client/index.js';import {HttpLink}from'@apollo/client/link/http/index.js';import {BatchHttpLink}from'@apollo/client/link/batch-http/index.js';import {onError}from'@apollo/client/link/error/index.js';import {GraphQLWsLink}from'@apollo/client/link/subscriptions/index.js';import {getOperationAST}from'graphql';import {invariant}from'ts-invariant';import {RetryLink}from'@apollo/client/link/retry/index.js';import {createClient}from'graphql-ws';import fetch from'cross-fetch';import {createCache,initializeCache}from'./base-apollo-cache.js';// apolloClient.ts
const schema = `
  # Add your schema here
`;
const errorLink = onError(({ graphQLErrors, networkError }) => {
    if (graphQLErrors) {
        graphQLErrors.map(({ message, locations, path }) => invariant.warn(`[GraphQL error]: Message: ${message}, Location: ${locations}, Path: ${path}`));
    }
    if (networkError) {
        invariant.warn(`[Network error]: ${networkError}`);
    }
});
const createApolloClient = ({ scope, isDev, isDebug, isSSR, getDataIdFromObject, clientState, httpGraphqlURL, httpLocalGraphqlURL, initialState, logger, }) => {
    logger.debug('Initializing Apollo Client with parameters, {%o}', {
        scope,
        isDev,
        isDebug,
        isSSR,
        httpGraphqlURL,
        httpLocalGraphqlURL,
    });
    const isBrowser = scope === 'browser';
    const isServer = scope === 'server';
    const cache = createCache({ getDataIdFromObject, clientState, logger });
    logger.debug('Created new Apollo memory cache');
    const retryLink = new RetryLink({
        attempts: async (count, operation, error) => {
            return false;
            // logger.debug('Retrying link attempt', { count, operation, error });
            // const promises = (clientState.retryLinkAttemptFuncs || []).map((func) => func(count, operation, error));
            // try {
            //     const result = await Promise.all(promises);
            //     return !!result.find((item) => item && isBoolean(item));
            // } catch (e) {
            //     logger.error('Error occurred in retryLink attempt condition', e);
            //     throw e;
            // }
        },
    });
    let link;
    if (isBrowser) {
        const connectionParams = async () => {
            logger.debug('Getting WebSocket connection parameters');
            const param = {};
            for (const connectionParam of clientState.connectionParams) {
                const result = await connectionParam();
                merge(param, await result());
            }
            return param;
        };
        const wsLink = new GraphQLWsLink(createClient({
            url: httpGraphqlURL.replace(/^http/, 'ws'),
            retryAttempts: 10,
            lazy: true,
            shouldRetry: () => true,
            keepAlive: 10000,
            connectionParams,
            on: {
                connected: (socket) => logger.debug('WebSocket connected'),
                error: async (error) => {
                    logger.error('WebSocket connection error', error);
                    const promises = (clientState.connectionCallbackFuncs || []).map((func) => func(wsLink, error, {}));
                    try {
                        await Promise.all(promises);
                    }
                    catch (err) {
                        logger.trace('Error occurred in WebSocket connection callback', err);
                        throw err;
                    }
                },
                ping: () => logger.trace('WebSocket ping sent'),
                pong: () => logger.trace('WebSocket pong received'),
            },
        }));
        link = ApolloLink.split(({ query, operationName }) => {
            if (operationName.endsWith('_WS')) {
                return true;
            }
            const operationAST = getOperationAST(query, operationName);
            return !!operationAST && operationAST.operation === 'subscription';
        }, wsLink, new HttpLink({ uri: httpGraphqlURL, credentials: 'include', fetch }));
    }
    else if (isServer) {
        logger.debug('Creating BatchHttpLink for server');
        link = new BatchHttpLink({
            uri: httpLocalGraphqlURL,
            fetch,
            batchInterval: 200,
            batchMax: 100,
            credentials: 'include',
        });
    }
    else {
        logger.debug('Creating HttpLink for native');
        link = new HttpLink({ uri: httpLocalGraphqlURL, fetch, credentials: 'include' });
    }
    const links = [errorLink, retryLink, ...(clientState.preLinks || []), link].filter(Boolean);
    const params = {
        queryDeduplication: true,
        typeDefs: schema.concat(clientState.typeDefs || ''),
        resolvers: clientState.resolvers,
        link: ApolloLink.from(links),
        cache,
        credentials: 'include',
        connectToDevTools: isBrowser && (isDev || isDebug),
    };
    if (isSSR) {
        if (isBrowser) {
            params.ssrForceFetchDelay = 100;
        }
        else if (isServer) {
            params.ssrMode = true;
        }
    }
    const apolloClient = new ApolloClient(params);
    logger.debug('Created new Apollo client');
    initializeCache({ cache, initialState, clientState, logger });
    return { apolloClient, cache };
};export{createApolloClient};
